@@ -651,6 +651,7 @@ void DiffList::runDiff(const std::shared_ptr<LineDataVector> &p1, const size_t i
 
             currentLine1 += (LineRef)(d.numberOfEquals() + d.diff1());
             currentLine2 += (LineRef)(d.numberOfEquals() + d.diff2());
+            assert(currentLine1 <= size1 && currentLine2 <= size2);
             push_back(d);
 
             p = e->link;
@@ -698,6 +699,7 @@ void DiffList::verify(const LineRef size1, const LineRef size2)
 
     for(const Diff& curDiff: *this)
     {
+        assert(curDiff.numberOfEquals() >= 0);
         assert(curDiff.diff1() <= TYPE_MAX(LineRef::LineType) && curDiff.diff2() <= TYPE_MAX(LineRef::LineType));
         l1 += curDiff.numberOfEquals() + LineRef(curDiff.diff1());
         l2 += curDiff.numberOfEquals() + LineRef(curDiff.diff2());
@@ -1544,7 +1546,7 @@ void Diff3LineList::calcDiff3LineVector(Diff3LineVector& d3lv)
     QtSizeType j = 0;
     for(i = begin(); i != end(); ++i, ++j)
     {
-        d3lv[j] = &(*i);
+        d3lv[j] = std::make_shared<Diff3Line>(*i);
     }
     assert(j == d3lv.size());
 }
