@@ -51,6 +51,7 @@
 #include <QPrintDialog>
 #include <QPrinter>
 #include <QPushButton>
+#include <QShortcut>
 #include <QSplitter>
 #include <QStatusBar>
 #include <QTextEdit>
@@ -149,7 +150,8 @@ KDiff3App::KDiff3App(QWidget* pParent, const QString& name, KDiff3Part* pKDiff3P
     pal.setColor(QPalette::Text, pal.color(QPalette::Active, QPalette::Text));
     setPalette(pal);
 
-    // Needed before any file operations via FileAccess happen.
+    // Setup progress ProgressDialog. No progress can be shown before this point.
+    // ProgressProxy will otherwise emit no-ops to disconnected boost signals.
     if(g_pProgressDialog == nullptr)
     {
         g_pProgressDialog = new ProgressDialog(this, statusBar());
@@ -318,6 +320,7 @@ KDiff3App::KDiff3App(QWidget* pParent, const QString& name, KDiff3Part* pKDiff3P
     m_pFindDialog = new FindDialog(this);
     chk_connect(m_pFindDialog, &FindDialog::findNext, this, &KDiff3App::slotEditFindNext);
 
+    mEscapeAction->setEnabled(m_pOptions->m_bEscapeKeyQuits);
     autoAdvance->setChecked(m_pOptions->m_bAutoAdvance);
     showWhiteSpaceCharacters->setChecked(m_pOptions->m_bShowWhiteSpaceCharacters);
     showWhiteSpace->setChecked(m_pOptions->m_bShowWhiteSpace);
@@ -343,9 +346,11 @@ KDiff3App::KDiff3App(QWidget* pParent, const QString& name, KDiff3Part* pKDiff3P
 
     m_pDirectoryMergeDock = new QDockWidget(i18n("Directory merge"), this);
     m_pDirectoryMergeWindow = new DirectoryMergeWindow(m_pDirectoryMergeDock, m_pOptions, *this);
+    m_pDirectoryMergeDock->setObjectName("DirectoryMergeDock");
     m_pDirectoryMergeDock->setWidget(m_pDirectoryMergeWindow);
     m_pDirectoryMergeDock->setFeatures(QDockWidget::DockWidgetMovable | QDockWidget::DockWidgetFloatable);
     m_pDirectoryMergeInfoDock = new QDockWidget(i18n("Merge info"), this);
+    m_pDirectoryMergeInfoDock->setObjectName("MergeInfoDock");
     m_pDirectoryMergeInfo = new DirectoryMergeInfo(m_pDirectoryMergeInfoDock);
     m_pDirectoryMergeInfoDock->setWidget(m_pDirectoryMergeInfo);
     m_pDirectoryMergeInfoDock->setFeatures(QDockWidget::DockWidgetMovable | QDockWidget::DockWidgetFloatable);
@@ -418,7 +423,7 @@ void KDiff3App::completeInit(const QString& fn1, const QString& fn2, const QStri
         m_sd3->setFilename(fn3);
     }
 
-    //should not happen now.
+    //Should not fail ever.
     assert(m_bDirCompare == m_sd1->isDir());
 
     if(m_bAutoFlag && m_bAutoMode && m_bDirCompare)
@@ -427,6 +432,37 @@ void KDiff3App::completeInit(const QString& fn1, const QString& fn2, const QStri
         m_bAutoMode = false;
     }
 
+    if(!isPart())
+    {
+        if(!m_pKDiff3Shell->isVisible() && !restoreWindow(KSharedConfig::openConfig()))
+        {
+            /*
+                Set default state/geometry from config file.
+                This will no longer be updated but serves as a fallback.
+                Qt's restoreState/saveState can handle multiple screens this won't.
+            */
+            if(m_pOptions->isFullScreen())
+                m_pKDiff3Shell->showFullScreen();
+            else if(m_pOptions->isMaximised())
+                m_pKDiff3Shell->showMaximized();
+
+            QSize size = m_pOptions->getGeometry();
+            QPoint pos = m_pOptions->getPosition();
+
+            if(!size.isEmpty())
+            {
+                m_pKDiff3Shell->resize(size);
+
+                QRect visibleRect = QRect(pos, size) & QApplication::desktop()->rect();
+                if(visibleRect.width() > 100 && visibleRect.height() > 100)
+                    m_pKDiff3Shell->move(pos);
+            }
+        }
+
+        m_pKDiff3Shell->show();
+    }
+    g_pProgressDialog->setStayHidden(false);
+
     bool bSuccess = true;
     if(m_bDirCompare)
         bSuccess = doDirectoryCompare(false);
@@ -482,38 +518,6 @@ void KDiff3App::completeInit(const QString& fn1, const QString& fn2, const QStri
     }
     m_bAutoMode = false;
 
-    if(!isPart())
-    {
-        if(!m_pKDiff3Shell->isVisible() && !restoreWindow(KSharedConfig::openConfig()))
-        {
-            /*
-                Set default state/geometry from config file.
-                This will no longer be updated but serves as a fallback.
-                Qt's restoreState/saveState can handle multiple screens this won't.
-            */
-            if(m_pOptions->isFullScreen())
-                m_pKDiff3Shell->showFullScreen();
-            else if(m_pOptions->isMaximised())
-                m_pKDiff3Shell->showMaximized();
-
-            QSize size = m_pOptions->getGeometry();
-            QPoint pos = m_pOptions->getPosition();
-
-            if(!size.isEmpty())
-            {
-                m_pKDiff3Shell->resize(size);
-
-                QRect visibleRect = QRect(pos, size) & QApplication::desktop()->rect();
-                if(visibleRect.width() > 100 && visibleRect.height() > 100)
-                    m_pKDiff3Shell->move(pos);
-            }
-        }
-
-        m_pKDiff3Shell->show();
-    }
-
-    g_pProgressDialog->setStayHidden(false);
-
     if(statusBar() != nullptr)
         statusBar()->setSizeGripEnabled(true);
 
@@ -691,12 +695,11 @@ void KDiff3App::initActions(KActionCollection* ac)
     dirViewToggle = GuiUtils::createAction<QAction>(i18n("Toggle Between Folder && Text View"), this, &KDiff3App::slotDirViewToggle, ac, "win_dir_view_toggle");
 
     m_pMergeEditorPopupMenu = new QMenu(this);
-    /*   chooseA->plug( m_pMergeEditorPopupMenu );
-       chooseB->plug( m_pMergeEditorPopupMenu );
-       chooseC->plug( m_pMergeEditorPopupMenu );*/
     m_pMergeEditorPopupMenu->addAction(chooseA);
     m_pMergeEditorPopupMenu->addAction(chooseB);
     m_pMergeEditorPopupMenu->addAction(chooseC);
+
+    mEscapeAction = new QShortcut(Qt::Key_Escape, this, this, &KDiff3App::slotFileQuit);
 }
 
 void KDiff3App::showPopupMenu(const QPoint& point)
@@ -715,17 +718,28 @@ void KDiff3App::initStatusBar()
 void KDiff3App::saveWindow(const KSharedConfigPtr config)
 {
     KConfigGroup group = config->group(KDIFF3_CONFIG_GROUP);
-
-    group.writeEntry("mainWindow-geometry", m_pKDiff3Shell->saveGeometry());
-    group.writeEntry("mainWindow-state", m_pKDiff3Shell->saveState());
+    group.writeEntry("mainWindow-geometry", saveGeometry());
+    group.writeEntry("mainWindow-state", saveState(1));
+    group.writeEntry("shell-geometry", m_pKDiff3Shell->saveGeometry());
+    group.writeEntry("shell-state", m_pKDiff3Shell->saveState());
 }
 
 bool KDiff3App::restoreWindow(const KSharedConfigPtr config)
 {
     KConfigGroup group = config->group(KDIFF3_CONFIG_GROUP);
+    if(m_pKDiff3Shell->restoreState(group.readEntry("mainWindow-state", QVariant(QByteArray())).toByteArray()))
+    {
+        bool r = m_pKDiff3Shell->restoreGeometry(group.readEntry("mainWindow-geometry", QVariant(QByteArray())).toByteArray());
+        group.deleteEntry("mainWindow-state");
+        group.deleteEntry("mainWindow-geometry");
+        saveWindow(config);
+        return r;
+    }
 
-    return (m_pKDiff3Shell->restoreGeometry(group.readEntry("mainWindow-geometry", QVariant(QByteArray())).toByteArray()) &&
-            m_pKDiff3Shell->restoreState(group.readEntry("mainWindow-state", QVariant(QByteArray())).toByteArray()));
+    return (restoreGeometry(group.readEntry("mainWindow-geometry", QVariant(QByteArray())).toByteArray()) &&
+            restoreState(group.readEntry("mainWindow-state", QVariant(QByteArray())).toByteArray(), 1)) &&
+           (m_pKDiff3Shell->restoreGeometry(group.readEntry("shell-geometry", QVariant(QByteArray())).toByteArray()) &&
+            m_pKDiff3Shell->restoreState(group.readEntry("shell-state", QVariant(QByteArray())).toByteArray()));
 }
 
 void KDiff3App::saveOptions(KSharedConfigPtr config)
