@@ -32,6 +32,7 @@
 #include <KMainWindow>
 #include <KSharedConfig>
 #include <KToggleAction>
+#include <QShortcut>
 
 // forward declaration of the KDiff3 classes
 class Options;
@@ -365,6 +366,7 @@ public Q_SLOTS:
     KToggleAction* viewToolBar = nullptr;
     KToggleAction* viewStatusBar;
 
+    QPointer<QShortcut> mEscapeAction;
     ////////////////////////////////////////////////////////////////////////
     // Special KDiff3 specific stuff starts here
     QPointer<QAction> editFind;
@@ -413,7 +415,6 @@ public Q_SLOTS:
 
     QWidget* m_pMainWidget = nullptr; // Contains vertical splitter and horiz scrollbar
     QWidget* m_pCentralWidget = nullptr;
-    QDockWidget* m_pMergeWindowDock = nullptr;
     QWidget* m_pMergeWindowFrame = nullptr;
     ReversibleScrollBar* m_pHScrollBar = nullptr;
 
