@@ -1,3 +1,4 @@
+// clang-format off
 /*
  * KDiff3 - Text Diff And Merge Tool
  *
@@ -57,11 +58,6 @@ class MergeResultWindow: public QWidget
 
     void setupConnections(const KDiff3App* app);
 
-    inline void clearMergeList()
-    {
-        m_mergeLineList.list().clear();
-    }
-
     static void initActions(KActionCollection* ac);
 
     void connectActions() const;
@@ -78,7 +74,7 @@ class MergeResultWindow: public QWidget
     int getNofVisibleLines() const;
     QString getSelection() const;
     void resetSelection();
-    void showNumberOfConflicts();
+    void showNumberOfConflicts(bool showIfNone = false);
     bool isDeltaAboveCurrent() const;
     bool isDeltaBelowCurrent() const;
     bool isConflictAboveCurrent() const;
