@@ -113,8 +113,12 @@ void KDiff3App::mainInit(TotalDiffStatus* pTotalDiffStatus, const InitFlags inFl
         setLockPainting(true);
     }
 
-    //insure merge result window never has stale iterators.
-    if(m_pMergeResultWindow) m_pMergeResultWindow->clearMergeList();
+    //insure merge result window never has stale iterators/[poiners.
+    if(m_pMergeResultWindow) m_pMergeResultWindow->reset();
+    //Clear stale pointers in DiffTextWindow.
+    if(m_pDiffTextWindow1) m_pDiffTextWindow1->reset();
+    if(m_pDiffTextWindow2) m_pDiffTextWindow2->reset();
+    if(m_pDiffTextWindow3) m_pDiffTextWindow3->reset();
     m_diff3LineList.clear();
     mDiff3LineVector.clear();
 
@@ -716,7 +720,7 @@ void KDiff3App::slotFinishMainInit()
     if(m_bLoadFiles)
     {
         if(bVisibleMergeResultWindow)
-            m_pMergeResultWindow->showNumberOfConflicts();
+            m_pMergeResultWindow->showNumberOfConflicts(!m_bAutoFlag);
         else if(
             // Avoid showing this message during startup without parameters.
             !(m_sd1->getAliasName().isEmpty() && m_sd2->getAliasName().isEmpty() && m_sd3->getAliasName().isEmpty()) &&
@@ -800,12 +804,6 @@ void KDiff3App::wheelEvent(QWheelEvent* pWheelEvent)
 
 void KDiff3App::keyPressEvent(QKeyEvent* keyEvent)
 {
-    if(keyEvent->key() == Qt::Key_Escape && m_pKDiff3Shell && m_pOptions->m_bEscapeKeyQuits)
-    {
-        m_pKDiff3Shell->close();
-        return;
-    }
-
     bool bCtrl = (keyEvent->modifiers() & Qt::ControlModifier) != 0;
 
     switch(keyEvent->key())
@@ -1301,6 +1299,7 @@ void KDiff3App::slotConfigure()
     m_pOptionDialog->setState();
     m_pOptionDialog->setMinimumHeight(m_pOptionDialog->minimumHeight() + 40);
     m_pOptionDialog->exec();
+    mEscapeAction->setEnabled(m_pOptions->m_bEscapeKeyQuits);
     slotRefresh();
 }
 
